@@ -718,9 +718,12 @@ evals <- function(txt, parse = TRUE, cache = TRUE, cache.mode = c('environment',
             file <- tempfile(pattern = rep[1], tmpdir = graph.dir, fileext = rep[2])
             file.name <- sub(sprintf('.%s$', graph.output), '', file)
         } else {
-            file <- file.path(gsub('\\', '/', graph.dir, fixed = TRUE), file)
-            file.name <- file.path(gsub('\\', '/', graph.dir, fixed = TRUE), file.name)
+            file <- file.path(graph.dir, file)
+            file.name <- file.path(graph.dir, file.name)
         }
+        file <- gsub('\\', '/', file, fixed = TRUE)
+        file.name <- gsub('\\', '/', file.name, fixed = TRUE)
+
 
         ## similar files counter
         if (grepl('%n', file.name)) {
